##' R Markdown Temlates for Journal of Data Science
##'
##' The \pkg{jds.rmd} package provides customized R Markdown templates and
##' formats for authoring and submitting articles to Journal of Data Science
##' (JDS).
##'
##' @name jds.rmd
##' @aliases jds.rmd-package
##' @keywords internal
"_PACKAGE"
